@@ -1152,7 +1152,7 @@ int32_t SPVM__Sys__IO__Constant__S_CDF(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_CDF;
   return 0;
 #else
-  return env->die(env, stack, "S_CDF is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_CDF is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1163,7 +1163,7 @@ int32_t SPVM__Sys__IO__Constant__S_ENFMT(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_ENFMT;
   return 0;
 #else
-  return env->die(env, stack, "S_ENFMT is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_ENFMT is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1174,7 +1174,7 @@ int32_t SPVM__Sys__IO__Constant__S_IF(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_IF;
   return 0;
 #else
-  return env->die(env, stack, "S_IF is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_IF is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1185,7 +1185,7 @@ int32_t SPVM__Sys__IO__Constant__S_IFBLK(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_IFBLK;
   return 0;
 #else
-  return env->die(env, stack, "S_IFBLK is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_IFBLK is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1196,7 +1196,7 @@ int32_t SPVM__Sys__IO__Constant__S_IFCHR(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_IFCHR;
   return 0;
 #else
-  return env->die(env, stack, "S_IFCHR is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_IFCHR is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1207,7 +1207,7 @@ int32_t SPVM__Sys__IO__Constant__S_IFCMP(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_IFCMP;
   return 0;
 #else
-  return env->die(env, stack, "S_IFCMP is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_IFCMP is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1218,7 +1218,7 @@ int32_t SPVM__Sys__IO__Constant__S_IFDIR(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_IFDIR;
   return 0;
 #else
-  return env->die(env, stack, "S_IFDIR is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_IFDIR is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1229,7 +1229,7 @@ int32_t SPVM__Sys__IO__Constant__S_IFDOOR(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_IFDOOR;
   return 0;
 #else
-  return env->die(env, stack, "S_IFDOOR is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_IFDOOR is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1240,7 +1240,7 @@ int32_t SPVM__Sys__IO__Constant__S_IFIFO(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_IFIFO;
   return 0;
 #else
-  return env->die(env, stack, "S_IFIFO is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_IFIFO is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1251,7 +1251,7 @@ int32_t SPVM__Sys__IO__Constant__S_IFLNK(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_IFLNK;
   return 0;
 #else
-  return env->die(env, stack, "S_IFLNK is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_IFLNK is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1262,7 +1262,7 @@ int32_t SPVM__Sys__IO__Constant__S_IFMPB(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_IFMPB;
   return 0;
 #else
-  return env->die(env, stack, "S_IFMPB is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_IFMPB is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1273,7 +1273,7 @@ int32_t SPVM__Sys__IO__Constant__S_IFMPC(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_IFMPC;
   return 0;
 #else
-  return env->die(env, stack, "S_IFMPC is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_IFMPC is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1284,7 +1284,7 @@ int32_t SPVM__Sys__IO__Constant__S_IFMT(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_IFMT;
   return 0;
 #else
-  return env->die(env, stack, "S_IFMT is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_IFMT is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1295,7 +1295,7 @@ int32_t SPVM__Sys__IO__Constant__S_IFNAM(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_IFNAM;
   return 0;
 #else
-  return env->die(env, stack, "S_IFNAM is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_IFNAM is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1306,7 +1306,7 @@ int32_t SPVM__Sys__IO__Constant__S_IFNWK(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_IFNWK;
   return 0;
 #else
-  return env->die(env, stack, "S_IFNWK is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_IFNWK is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1317,7 +1317,7 @@ int32_t SPVM__Sys__IO__Constant__S_IFREG(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_IFREG;
   return 0;
 #else
-  return env->die(env, stack, "S_IFREG is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_IFREG is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1328,7 +1328,7 @@ int32_t SPVM__Sys__IO__Constant__S_IFSHAD(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_IFSHAD;
   return 0;
 #else
-  return env->die(env, stack, "S_IFSHAD is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_IFSHAD is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1339,7 +1339,7 @@ int32_t SPVM__Sys__IO__Constant__S_IFSOCK(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_IFSOCK;
   return 0;
 #else
-  return env->die(env, stack, "S_IFSOCK is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_IFSOCK is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1350,7 +1350,7 @@ int32_t SPVM__Sys__IO__Constant__S_IFWHT(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_IFWHT;
   return 0;
 #else
-  return env->die(env, stack, "S_IFWHT is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_IFWHT is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1361,7 +1361,7 @@ int32_t SPVM__Sys__IO__Constant__S_INSEM(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_INSEM;
   return 0;
 #else
-  return env->die(env, stack, "S_INSEM is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_INSEM is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1372,7 +1372,7 @@ int32_t SPVM__Sys__IO__Constant__S_INSHD(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_INSHD;
   return 0;
 #else
-  return env->die(env, stack, "S_INSHD is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_INSHD is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1383,7 +1383,7 @@ int32_t SPVM__Sys__IO__Constant__S_IREAD(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_IREAD;
   return 0;
 #else
-  return env->die(env, stack, "S_IREAD is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_IREAD is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1394,7 +1394,7 @@ int32_t SPVM__Sys__IO__Constant__S_IRGRP(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_IRGRP;
   return 0;
 #else
-  return env->die(env, stack, "S_IRGRP is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_IRGRP is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1405,7 +1405,7 @@ int32_t SPVM__Sys__IO__Constant__S_IROTH(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_IROTH;
   return 0;
 #else
-  return env->die(env, stack, "S_IROTH is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_IROTH is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1416,7 +1416,7 @@ int32_t SPVM__Sys__IO__Constant__S_IRUSR(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_IRUSR;
   return 0;
 #else
-  return env->die(env, stack, "S_IRUSR is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_IRUSR is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1427,7 +1427,7 @@ int32_t SPVM__Sys__IO__Constant__S_IRWXG(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_IRWXG;
   return 0;
 #else
-  return env->die(env, stack, "S_IRWXG is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_IRWXG is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1438,7 +1438,7 @@ int32_t SPVM__Sys__IO__Constant__S_IRWXO(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_IRWXO;
   return 0;
 #else
-  return env->die(env, stack, "S_IRWXO is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_IRWXO is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1449,7 +1449,7 @@ int32_t SPVM__Sys__IO__Constant__S_IRWXU(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_IRWXU;
   return 0;
 #else
-  return env->die(env, stack, "S_IRWXU is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_IRWXU is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1460,7 +1460,7 @@ int32_t SPVM__Sys__IO__Constant__S_ISBLK(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_ISBLK(stack[0].ival);
   return 0;
 #else
-  return env->die(env, stack, "S_ISBLK is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_ISBLK is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1471,7 +1471,7 @@ int32_t SPVM__Sys__IO__Constant__S_ISCHR(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_ISCHR(stack[0].ival);
   return 0;
 #else
-  return env->die(env, stack, "S_ISCHR is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_ISCHR is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1482,7 +1482,7 @@ int32_t SPVM__Sys__IO__Constant__S_ISDIR(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_ISDIR(stack[0].ival);
   return 0;
 #else
-  return env->die(env, stack, "S_ISDIR is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_ISDIR is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1493,7 +1493,7 @@ int32_t SPVM__Sys__IO__Constant__S_ISFIFO(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_ISFIFO(stack[0].ival);
   return 0;
 #else
-  return env->die(env, stack, "S_ISFIFO is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_ISFIFO is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1504,7 +1504,7 @@ int32_t SPVM__Sys__IO__Constant__S_ISGID(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_ISGID;
   return 0;
 #else
-  return env->die(env, stack, "S_ISGID is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_ISGID is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1515,7 +1515,7 @@ int32_t SPVM__Sys__IO__Constant__S_ISLNK(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_ISLNK(stack[0].ival);
   return 0;
 #else
-  return env->die(env, stack, "S_ISLNK is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_ISLNK is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1526,7 +1526,7 @@ int32_t SPVM__Sys__IO__Constant__S_ISREG(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_ISREG(stack[0].ival);
   return 0;
 #else
-  return env->die(env, stack, "S_ISREG is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_ISREG is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1537,7 +1537,7 @@ int32_t SPVM__Sys__IO__Constant__S_ISSOCK(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_ISSOCK(stack[0].ival);
   return 0;
 #else
-  return env->die(env, stack, "S_ISSOCK is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_ISSOCK is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1548,7 +1548,7 @@ int32_t SPVM__Sys__IO__Constant__S_ISUID(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_ISUID;
   return 0;
 #else
-  return env->die(env, stack, "S_ISUID is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_ISUID is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1559,7 +1559,7 @@ int32_t SPVM__Sys__IO__Constant__S_ISVTX(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_ISVTX;
   return 0;
 #else
-  return env->die(env, stack, "S_ISVTX is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_ISVTX is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1570,7 +1570,7 @@ int32_t SPVM__Sys__IO__Constant__S_IWGRP(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_IWGRP;
   return 0;
 #else
-  return env->die(env, stack, "S_IWGRP is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_IWGRP is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1581,7 +1581,7 @@ int32_t SPVM__Sys__IO__Constant__S_IWOTH(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_IWOTH;
   return 0;
 #else
-  return env->die(env, stack, "S_IWOTH is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_IWOTH is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1592,7 +1592,7 @@ int32_t SPVM__Sys__IO__Constant__S_IWUSR(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_IWUSR;
   return 0;
 #else
-  return env->die(env, stack, "S_IWUSR is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_IWUSR is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1603,7 +1603,7 @@ int32_t SPVM__Sys__IO__Constant__S_IXGRP(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_IXGRP;
   return 0;
 #else
-  return env->die(env, stack, "S_IXGRP is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_IXGRP is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1614,7 +1614,7 @@ int32_t SPVM__Sys__IO__Constant__S_IXOTH(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_IXOTH;
   return 0;
 #else
-  return env->die(env, stack, "S_IXOTH is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_IXOTH is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
@@ -1625,7 +1625,7 @@ int32_t SPVM__Sys__IO__Constant__S_IXUSR(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = S_IXUSR;
   return 0;
 #else
-  return env->die(env, stack, "S_IXUSR is not defined in this system", __func__, FILE_NAME, __LINE__);
+  return env->die(env, stack, "S_IXUSR is not defined on this system", __func__, FILE_NAME, __LINE__);
 #endif
 
 }
