@@ -81,17 +81,17 @@ int32_t SPVM__Sys__Select__FD_SET(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t fd = stack[0].ival;
 
   if (!(fd >= 0)) {
-    return env->die(env, stack, "The $fd must be greater than or equal to 0", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The $fd must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
   }
 
   if (!(fd < FD_SETSIZE)) {
-    return env->die(env, stack, "The $fd must be less than FD_SETSIZE", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The $fd must be less than FD_SETSIZE", __func__, FILE_NAME, __LINE__);
   }
 
   void* obj_set = stack[1].oval;
 
   if (!obj_set) {
-    return env->die(env, stack, "The $set must be defined", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The $set must be defined", __func__, FILE_NAME, __LINE__);
   }
 
   fd_set* set = env->get_pointer(env, stack, obj_set);
@@ -106,17 +106,17 @@ int32_t SPVM__Sys__Select__FD_CLR(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t fd = stack[0].ival;
 
   if (!(fd >= 0)) {
-    return env->die(env, stack, "The $fd must be greater than or equal to 0", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The $fd must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
   }
 
   if (!(fd < FD_SETSIZE)) {
-    return env->die(env, stack, "The $fd must be less than FD_SETSIZE", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The $fd must be less than FD_SETSIZE", __func__, FILE_NAME, __LINE__);
   }
 
   void* obj_set = stack[1].oval;
 
   if (!obj_set) {
-    return env->die(env, stack, "The $set must be defined", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The $set must be defined", __func__, FILE_NAME, __LINE__);
   }
 
   fd_set* set = env->get_pointer(env, stack, obj_set);
@@ -131,17 +131,17 @@ int32_t SPVM__Sys__Select__FD_ISSET(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t fd = stack[0].ival;
 
   if (!(fd >= 0)) {
-    return env->die(env, stack, "The $fd must be greater than or equal to 0", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The $fd must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
   }
 
   if (!(fd < FD_SETSIZE)) {
-    return env->die(env, stack, "The $fd must be less than FD_SETSIZE", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The $fd must be less than FD_SETSIZE", __func__, FILE_NAME, __LINE__);
   }
 
   void* obj_set = stack[1].oval;
 
   if (!obj_set) {
-    return env->die(env, stack, "The $set must be defined", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The $set must be defined", __func__, FILE_NAME, __LINE__);
   }
 
   fd_set* set = env->get_pointer(env, stack, obj_set);
@@ -157,10 +157,10 @@ int32_t SPVM__Sys__Select__select(SPVM_ENV* env, SPVM_VALUE* stack) {
 
   int32_t fd = stack[0].ival;
   if (!(fd >= 0)) {
-    return env->die(env, stack, "The $fd must be greater than or equal to 0", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The $fd must be greater than or equal to 0", __func__, FILE_NAME, __LINE__);
   }
   if (!(fd < FD_SETSIZE)) {
-    return env->die(env, stack, "The $fd must be less than FD_SETSIZE", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The $fd must be less than FD_SETSIZE", __func__, FILE_NAME, __LINE__);
   }
   
   void* obj_readfds = stack[1].oval;
@@ -190,7 +190,7 @@ int32_t SPVM__Sys__Select__select(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t updated_fds_count = select(fd, readfds, writefds, exceptfds, timeout);
   
   if (updated_fds_count == -1) {
-    env->die(env, stack, "[System Error]select failed: %s", socket_strerror(env, stack, socket_errno(), 0), FILE_NAME, __LINE__);
+    env->die(env, stack, "[System Error]select failed: %s", socket_strerror(env, stack, socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
 
